go-hentai-scraper

command module
v1.0.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2021 License: MIT Imports: 9 Imported by: 0

README

go-hentai-scraper

GitHub Workflow Status

This scraper is not using official APIs since some of them have limitations. Unfortunatly this also means that for some sites it might take longer to download content because the connection can be restricted. Also some sites only provide single downloads, downloads to lesser qualities or no downloads at all. This scraper will always give you the opportunity to download the best available quality from each site.

Installation

If you don't want to build the app yourself checkout the releases page.

Otherwise you can clone this repository yourself and download it. Then use Golang to build it yourself:

go build

After that you should be provided with an executable.

Or if you got Golang already installed you can download the source code and replace the executable with this:

go run main.go ...

Getting started

Usage:

go-hentai-scraper [OPTIONS] URL [URLs...]
Download example
go-hentai-scraper https://hanime.tv/videos/hentai/kuro-gal-ni-natta-kara-shin-yuu-to-shite-mita-season-1

Note: wrap the URL(s) in quotation marks if it contains special characters.
go-hentai-scraper "https://..."

The -i option displays all available quality of video without downloading.

go-hentai-scraper -i https://hanime.tv/videos/hentai/netosis-1

 Site:      https://hanime.tv/
 Title:     Netosis 1
 Type:      video
 Streams:   # All available qualities
     [0]  -------------------
     Info:            netosis-1-1080p-v1x.mp4-v1x.m3u8
     Quality:         1080p; 1920 x 1080
     Parts:           55
     Size:            276.00 MB (276000000 Bytes)
     # download with: go-hentai-scraper -s 0 ...


     [1]  -------------------
     Info:            netosis-1-720p-v1x.mp4-v1x.m3u8
     Quality:         720p; 1280 x 720
     Parts:           55
     Size:            141.00 MB (141000000 Bytes)
     # download with: go-hentai-scraper -s 1 ...


     [2]  -------------------
     Info:            netosis-1-480p-v1x.mp4-v1x.m3u8
     Quality:         480p; 854 x 480
     Parts:           56
     Size:            69.00 MB (69000000 Bytes)
     # download with: go-hentai-scraper -s 2 ...


     [3]  -------------------
     Info:            netosis-1-360p-v1x.mp4-v1x.m3u8
     Quality:         360p; 640 x 360
     Parts:           56
     Size:            49.00 MB (49000000 Bytes)
     # download with: go-hentai-scraper -s 3 ...

The default stream is 0 and it also offers the best available quality. If you want to download a different quality or from a mirrored server you can manually choose a stream with -s.

Multiple inputs

You can also download multiple URLs at once:

go-hentai-scraper -i https://nhentai.net/g/364616/ https://nhentai.net/g/364591/

 Site:      https://nhentai.net
 Title:     Matsuri tte Iina
 Type:      image
 Streams:   # All available qualities
     [0]  -------------------
     Quality:         unknown
     Parts:           31
     Size:            0.00 MB (0 Bytes)
     # download with: go-hentai-scraper -s 0 ...


 Site:      https://nhentai.net
 Title:     ASSTROLOGIC
 Type:      image
 Streams:   # All available qualities
     [0]  -------------------
     Quality:         unknown
     Parts:           36
     Size:            0.00 MB (0 Bytes)
     # download with: go-hentai-scraper -s 0 ...

The URLs will be downloaded one by one.

Options


 -o             Output name of the file

 go-hentai-scraper -o myfilename http...

--------------------------------------------------------------------------------

 -O             Output path of the files

 go-hentai-scraper -O C://Users//User//Downloads// http...

--------------------------------------------------------------------------------

 -r             Restrict content -> don't download senisble content (e-hentai.org only)

 go-hentai-scraper -r http...

--------------------------------------------------------------------------------

 -j             Show extracted data for the provided URL

 go-hentai-scraper -j http...

--------------------------------------------------------------------------------

 -i             Show info for the provided URL

 go-hentai-scraper -i http...

--------------------------------------------------------------------------------

 -s             Select a specific stream | 0 is default and the best quality of that stream

 go-hentai-scraper -s 0 http...

--------------------------------------------------------------------------------

 -w             Number of download workers

 go-hentai-scraper -w 4 http...

--------------------------------------------------------------------------------

 -a              Amount of files (image boards only)

 go-hentai-scraper -a 5000 http...

--------------------------------------------------------------------------------

 -p              Enter pages like 1,2,3-4,6,7,8-9 for doujins

 go-hentai-scraper -p 1,2,3-4 http...

Supported sites

Site Images Videos
9hentai.to/ru ✔ ?
animeidhentai.com (1080p, 720p, 480p, 360p) ? ✔
booruproject (ex. rule34, gelbooru) ✔ ✔
booru.io ✔ ?
comicporn.xxx ✔ ?
damn.stream(720p, 480p, 360p) ? ✔
danbooru.donmai.us ✔ ?
doujin.sexy ✔ ?
e-hentai.org ✔ ?
ecchi.iwara.tv ✔ ✔
exhentai.org* ✔ ?
hanime.tv(1080p, 720p, 480p, 360p) ✔ ✔
hentai2read.com ✔ ?
hentai2w.com(720p, 480p, 360p) ? ✔
hentaicloud.com(720p) ❌ ✔
hentaidude.com(720p, 480, 360p) ? ✔
hentaiera.com ✔ ?
hentaifox.com ✔ ?
hentaihaven.red (1080p, 720p, 480p, 360p) ? ✔
hentaihaven.xxx (1080p, 720p, 480p, 360p) ? ✔
hentaimama.io(1080p, 720p) ? ✔
hentais.tube (720p, 480p, 360p) ? ✔
hentaistream.moe (2160p, 1080p, 480p) ? ✔
hentaistream.xxx (1080p, 720, 480p, 360p) ? ✔
hentaiworld.tv (1080p, 720p, 480p) ? ✔
hentai.tv (1080p, 720p, 480p, 360p) ? ✔
hentai.pro (1080p, 720p, 480p, 360p) ? ✔
hentaiyes.com (1080p, 720p, 480p, 360p) ? ✔
hitomi.la ✔ ?
imhentai.com ✔ ?
konachan.com ✔ ?
miohentai.com (1080p, 720p, 480p) ✔ ✔
muchohentai.com (1080p, 720p, 480p, 360p) ? ✔
nhentai.net ✔ ?
ohentai.org (1080p, 720p, 480p) ? ✔
pururin.io ✔ ?
rule34.paheal.net ✔ ✔
simply-hentai.com ✔ ?
thehentaiworld.com ✔ ✔
yandere.re ✔ ?

*you need a login for this site. You can supply it via the parameters -un and -up

If your site is not listed - you can still try to use the universal downloader.

Credit

  • Thanks to annie for the great template

Donate

You won't gain extra benefits from it. Although it's very much appriciated.

XMR 4AFThbPDiig6tEZdRL4NnvDfqPETiuewDgpCJKkSs11BGCVqoydRUHkZr5cotGMx395V7c2swDxi5Xjhbztiqyod7P31szF

Licencse

Pretty sure MIT is the way to go

Documentation

The Go Gopher

There is no documentation for this package.

Jump to

Keyboard shortcuts

? : This menu
/ : Search site
f or F : Jump to
y or Y : Canonical URL